### How to use the Wordlist-Editor

In order to use the wordlist editor, you will need a valid input file. This file should be structured as a Wordlist file with the first line indicating the names of all columns and the first column pointing to a unique ID for each row of the file.

#### Key Bindings

- [F1] Toggle this help message.
- [F2] Toggle the settings.
- [F3] Toggle the filters.
- [F4] Toggle all columns / basic columns.
- [CTRL+I] Go to first cell (insert mode).
- [CTRL+LEFT] Go to left cell (insert mode).
- [CTRL+RIGHT] Got to right cell (insert mode).
- [ESC] Exit insert mode without saving (insert mode).
- [ENTER] Exit insert mode and save (insert mode).
- [RIGHT MOUSE CLICK] Show related entries (works only, if the given entry is selected as the current format option).
- [PAGE UP] Go to previous rows.
- [PAGE DOWN] Go to following rows.
- [LEFT+ALT] Move table to the left.
- [RIGHT+ALT] Move table to the right.

#### Filtering

The Wordlist-Editor allows you to filter the entries in multiple ways. With help of the text fields, you can select that only

- specific taxa,
- specific concepts, or
- specific columns
- specific entries

are displayed. For taxa and concepts, just type in the name of the taxon or concept you want to select and separate multiple taxa and concept by a comma. For the filtering of columns, you may also toggle between the display of the basic columns (default) and all columns by pressing [F4], or you may select the columns within the settings menu (press [F2] to show or close the settings). In order to filter specific entries, type "COLUMNNAME = entry", where COLUMNAME is the name of one of the columns in the data, and entry is one entry you want to search for. Using "=" will search for all entries which contain the given string. If you want to search for a direct match, use "==" instead.

#### Navigation

Having entered the insert mode (just click on any of the cells of the table or press [CTRL+I]), you can navigate with key up and key down from cell to cell along the same column. If you want to navigate between columns within the same row, use [CTRL+LEFT] and [CTRL+RIGHT]. Having modified the content of a cell, you can submit the modification by navigating to the next neighboring cell or by pressing [ENTER]. The letter will also close the insert mode. In order to leave the insert mode without submitting any modifications, just press [ESC].

#### Libraries used in the EDICTOR

- Springy.js